@@ -3,10 +3,8 @@ import math
 import statistics
 from typing import List, Optional, Set
 
-from ..align import SplitAlignment, call_paired_read_event, call_read_events, convert_to_duplication
-from ..assemble import Contig
 from ..bam import read as _read
-from ..breakpoint import Breakpoint, BreakpointPair
+from ..breakpoint import Breakpoint, BreakpointPair, classify_breakpoint_pair
 from ..constants import (
     CALL_METHOD,
     COLUMNS,
@@ -18,6 +16,13 @@ from ..constants import (
 )
 from ..interval import Interval
 from ..validate.base import Evidence
+from .align import (
+    DiscontinuousAlignment,
+    call_paired_read_event,
+    call_read_events,
+    convert_to_duplication,
+)
+from .assemble import Contig
 
 
 class EventCall(BreakpointPair):
@@ -34,7 +39,7 @@ class EventCall(BreakpointPair):
     compatible_flanking_pairs: Set
     compatible_type: Optional[str]
     contig: Optional[Contig]
-    contig_alignment: Optional[SplitAlignment]
+    contig_alignment: Optional[DiscontinuousAlignment]
 
     @property
     def has_compatible(self):
@@ -48,7 +53,7 @@ class EventCall(BreakpointPair):
         event_type: str,
         call_method: str,
         contig: Optional[Contig] = None,
-        contig_alignment: Optional[SplitAlignment] = None,
+        contig_alignment: Optional[DiscontinuousAlignment] = None,
         untemplated_seq: Optional[str] = None,
     ):
         """
@@ -84,10 +89,10 @@ class EventCall(BreakpointPair):
         else:
             self.compatible_type = None
         # use the distance function from the source evidence to narrow the possible types
-        putative_types = BreakpointPair.classify(self, source_evidence.distance)
+        putative_types = classify_breakpoint_pair(self, source_evidence.distance)
         if event_type not in putative_types and self.compatible_type in putative_types:
             event_type, self.compatible_type = self.compatible_type, event_type
-            putative_types = BreakpointPair.classify(self, source_evidence.distance)
+            putative_types = classify_breakpoint_pair(self, source_evidence.distance)
 
         self.data[COLUMNS.event_type] = SVTYPE.enforce(event_type)
         if event_type not in putative_types | {self.compatible_type}:
@@ -172,7 +177,7 @@ class EventCall(BreakpointPair):
         return not all(
             [
                 {self.event_type, self.compatible_type}
-                & BreakpointPair.classify(self.source_evidence),
+                & classify_breakpoint_pair(self.source_evidence),
                 self.break1 & self.source_evidence.outer_window1,
                 self.break2 & self.source_evidence.outer_window2,
                 self.break1.chr == self.source_evidence.break1.chr,
@@ -236,8 +241,8 @@ class EventCall(BreakpointPair):
                 else:  # L R
                     if not all(
                         [
-                            read.reference_start + 1 <= self.break1.end,
-                            mate.reference_end >= self.break2.start,
+                            read.reference_end <= self.break1.end,
+                            mate.reference_start >= self.break2.start,
                         ]
                     ):
                         continue
@@ -300,7 +305,7 @@ class EventCall(BreakpointPair):
             read (pysam.AlignedSegment): putative spanning read
         """
         for event in call_read_events(read, is_stranded=self.source_evidence.bam_cache.stranded):
-            if event == self and self.event_type in BreakpointPair.classify(
+            if event == self and self.event_type in classify_breakpoint_pair(
                 event, distance=self.source_evidence.distance
             ):
                 self.spanning_reads.add(read)
@@ -515,13 +520,13 @@ class EventCall(BreakpointPair):
         if self.contig:
             cseq = self.contig_alignment.query_sequence
             try:
-                break1_read_depth = SplitAlignment.breakpoint_contig_remapped_depth(
+                break1_read_depth = DiscontinuousAlignment.breakpoint_contig_remapped_depth(
                     self.break1, self.contig, self.contig_alignment.read1
                 )
             except AssertionError:
                 break1_read_depth = None
             try:
-                break2_read_depth = SplitAlignment.breakpoint_contig_remapped_depth(
+                break2_read_depth = DiscontinuousAlignment.breakpoint_contig_remapped_depth(
                     self.break2,
                     self.contig,
                     self.contig_alignment.read1
@@ -562,7 +567,7 @@ def _call_by_contigs(source_evidence):
         for aln in ctg.alignments:
             if aln.is_putative_indel and aln.net_size(source_evidence.distance) == Interval(0):
                 continue
-            for event_type in BreakpointPair.classify(aln, distance=source_evidence.distance):
+            for event_type in classify_breakpoint_pair(aln, distance=source_evidence.distance):
                 try:
                     new_event = EventCall(
                         aln.break1,
@@ -655,8 +660,10 @@ def _call_by_spanning_reads(source_evidence: Evidence, consumed_evidence):
             None  # unless we are collecting a consensus we shouldn't assign sequences to the breaks
         )
         event.break2.seq = None
-        types = BreakpointPair.classify(source_evidence) | {source_evidence.compatible_type}
-        for event_type in types & BreakpointPair.classify(event, distance=source_evidence.distance):
+        types = classify_breakpoint_pair(source_evidence) | {source_evidence.compatible_type}
+        for event_type in types & classify_breakpoint_pair(
+            event, distance=source_evidence.distance
+        ):
             try:
                 new_event = EventCall(
                     event.break1,
@@ -1076,7 +1083,7 @@ def _call_by_split_reads(evidence, event_type, consumed_evidence=None):
                     event_type,
                     call_method=CALL_METHOD.SPLIT,
                     untemplated_seq=call.untemplated_seq,
-                    contig_alignment=None if not isinstance(call, SplitAlignment) else call,
+                    contig_alignment=None if not isinstance(call, DiscontinuousAlignment) else call,
                 )
             except ValueError:  # incompatible types
                 continue
